package com.ruoyi.szxc.service;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcWorkRecard;

/**
 * 工作记录Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcWorkRecardService 
{
    /**
     * 查询工作记录
     * 
     * @param id 工作记录主键
     * @return 工作记录
     */
    public SzxcWorkRecard selectSzxcWorkRecardById(Long id);

    /**
     * 查询工作记录列表
     * 
     * @param szxcWorkRecard 工作记录
     * @return 工作记录集合
     */
    public List<SzxcWorkRecard> selectSzxcWorkRecardList(SzxcWorkRecard szxcWorkRecard);

    /**
     * 新增工作记录
     * 
     * @param szxcWorkRecard 工作记录
     * @return 结果
     */
    public int insertSzxcWorkRecard(SzxcWorkRecard szxcWorkRecard);

    /**
     * 修改工作记录
     * 
     * @param szxcWorkRecard 工作记录
     * @return 结果
     */
    public int updateSzxcWorkRecard(SzxcWorkRecard szxcWorkRecard);

    /**
     * 批量删除工作记录
     * 
     * @param ids 需要删除的工作记录主键集合
     * @return 结果
     */
    public int deleteSzxcWorkRecardByIds(Long[] ids);

    /**
     * 删除工作记录信息
     * 
     * @param id 工作记录主键
     * @return 结果
     */
    public int deleteSzxcWorkRecardById(Long id);
}
